package com.ruoyi.project.production.mapper;

import java.util.List;
import com.ruoyi.framework.aspectj.lang.annotation.DataScope;
import com.ruoyi.project.production.domain.TPpeStaffLocker;

/**
 * 自行车棚员工PPE柜Mapper接口
 *
 * @author ssy
 * @date 2023-11-30
 */
public interface TPpeStaffLockerMapper
{
    /**
     * 查询自行车棚员工PPE柜
     *
     * @param id 自行车棚员工PPE柜ID
     * @return 自行车棚员工PPE柜
     */
    public TPpeStaffLocker selectTPpeStaffLockerById(Long id);

    /**
     * 查询自行车棚员工PPE柜列表
     *
     * @param tPpeStaffLocker 自行车棚员工PPE柜
     * @return 自行车棚员工PPE柜集合
     */
    @DataScope(deptAlias = "d")
    public List<TPpeStaffLocker> selectTPpeStaffLockerList(TPpeStaffLocker tPpeStaffLocker);

    @DataScope(deptAlias = "d")
    public List<TPpeStaffLocker> selectTPpeStaffLockerListByMainId(Long mainId);

    /**
     * 新增自行车棚员工PPE柜
     *
     * @param tPpeStaffLocker 自行车棚员工PPE柜
     * @return 结果
     */
    public int insertTPpeStaffLocker(TPpeStaffLocker tPpeStaffLocker);

    /**
     * 修改自行车棚员工PPE柜
     *
     * @param tPpeStaffLocker 自行车棚员工PPE柜
     * @return 结果
     */
    public int updateTPpeStaffLocker(TPpeStaffLocker tPpeStaffLocker);

    /**
     * 删除自行车棚员工PPE柜
     *
     * @param id 自行车棚员工PPE柜ID
     * @return 结果
     */
    public int deleteTPpeStaffLockerById(Long id);

    /**
     * 批量删除自行车棚员工PPE柜
     *
     * @param ids 需要删除的数据ID
     * @return 结果
     */
    public int deleteTPpeStaffLockerByIds(Long[] ids);
}
